@@ -4,7 +4,6 @@ from cqlengine.models import Model
 from uuid import uuid4
 from cqlengine import columns
 import mock
-from cqlengine.connection import ConnectionPool
 from cqlengine import ALL, BatchQuery
 
 class TestConsistencyModel(Model):
@@ -29,11 +28,11 @@ class TestConsistency(BaseConsistencyTest):
     def test_create_uses_consistency(self):
 
         qs = TestConsistencyModel.consistency(ALL)
-        with mock.patch.object(ConnectionPool, 'execute') as m:
+        with mock.patch.object(self.session, 'execute') as m:
             qs.create(text="i am not fault tolerant this way")
 
         args = m.call_args
-        self.assertEqual(ALL, args[0][2])
+        self.assertEqual(ALL, args[0][0].consistency_level)
 
     def test_queryset_is_returned_on_create(self):
         qs = TestConsistencyModel.consistency(ALL)
@@ -43,39 +42,40 @@ class TestConsistency(BaseConsistencyTest):
         t = TestConsistencyModel.create(text="bacon and eggs")
         t.text = "ham sandwich"
 
-        with mock.patch.object(ConnectionPool, 'execute') as m:
+        with mock.patch.object(self.session, 'execute') as m:
             t.consistency(ALL).save()
 
         args = m.call_args
-        self.assertEqual(ALL, args[0][2])
+        self.assertEqual(ALL, args[0][0].consistency_level)
 
 
     def test_batch_consistency(self):
 
-        with mock.patch.object(ConnectionPool, 'execute') as m:
+        with mock.patch.object(self.session, 'execute') as m:
             with BatchQuery(consistency=ALL) as b:
                 TestConsistencyModel.batch(b).create(text="monkey")
 
         args = m.call_args
-        self.assertEqual(ALL, args[0][2])
 
-        with mock.patch.object(ConnectionPool, 'execute') as m:
+        self.assertEqual(ALL, args[0][0].consistency_level)
+
+        with mock.patch.object(self.session, 'execute') as m:
             with BatchQuery() as b:
                 TestConsistencyModel.batch(b).create(text="monkey")
 
         args = m.call_args
-        self.assertNotEqual(ALL, args[0][2])
+        self.assertNotEqual(ALL, args[0][0].consistency_level)
 
     def test_blind_update(self):
         t = TestConsistencyModel.create(text="bacon and eggs")
         t.text = "ham sandwich"
         uid = t.id
 
-        with mock.patch.object(ConnectionPool, 'execute') as m:
+        with mock.patch.object(self.session, 'execute') as m:
             TestConsistencyModel.objects(id=uid).consistency(ALL).update(text="grilled cheese")
 
         args = m.call_args
-        self.assertEqual(ALL, args[0][2])
+        self.assertEqual(ALL, args[0][0].consistency_level)
 
 
     def test_delete(self):
@@ -84,11 +84,11 @@ class TestConsistency(BaseConsistencyTest):
         t.text = "ham and cheese sandwich"
         uid = t.id
 
-        with mock.patch.object(ConnectionPool, 'execute') as m:
+        with mock.patch.object(self.session, 'execute') as m:
             t.consistency(ALL).delete()
 
-        with mock.patch.object(ConnectionPool, 'execute') as m:
+        with mock.patch.object(self.session, 'execute') as m:
             TestConsistencyModel.objects(id=uid).consistency(ALL).delete()
 
         args = m.call_args
-        self.assertEqual(ALL, args[0][2])
+        self.assertEqual(ALL, args[0][0].consistency_level)
